@@ -72,7 +72,9 @@ def correct_insertion_codes(pdb_in, pdb_out, insertion_offset=3000):
     return renumbered_res
 
 
-def mend_pdb(pdb_to_clean, pdb_cleaned, ff, ffout, logfile="LOG_pdb2pqr", hopt=True):
+def mend_pdb(
+    pdb_to_clean, pdb_cleaned, ff, ffout, logfile="LOG_pdb2pqr", hopt=True, debug=False
+):
     pdb_fixed = pdb_to_clean.replace(".pdb", "_fixed.pdb")
     renumbered_res = correct_insertion_codes(pdb_to_clean, pdb_fixed)
     try:
@@ -102,6 +104,8 @@ def mend_pdb(pdb_to_clean, pdb_cleaned, ff, ffout, logfile="LOG_pdb2pqr", hopt=T
                 e.stderr.decode("ascii")
             )
         )
+    if not debug:
+        os.system("rm -f {}".format(pdb_fixed))
     return renumbered_res
 
 
@@ -432,4 +436,4 @@ def rm_cys_bridges(chains_res, logfile_mend):
                 continue
             final_chains_res[chain][res] = chains_res[chain][res]
 
-    return final_chains_res, cys_bridges
\ No newline at end of file
+    return final_chains_res, cys_bridges
